UartConfig

Struct UartConfig 

#[non_exhaustive]
pub struct UartConfig { pub baudrate: HertzU32, pub data_bits: DataBits, pub stop_bits: StopBits, pub parity: Option<Parity>, }
A struct holding the configuration for an UART device.

The Default implementation implements the following values:

UartConfig {
   baudrate: Baud(115_200),
   data_bits: DataBits::Eight,
   stop_bits: StopBits::One,
   parity: None,
}

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
baudrate: HertzU32

The baudrate the uart will run at.

data_bits: DataBits

The amount of data bits the uart should be configured to.

stop_bits: StopBits

The amount of stop bits the uart should be configured to.

parity: Option<Parity>

The parity that this uart should have

Implementations

Source

impl UartConfig

pub const fn new( baudrate: HertzU32, data_bits: DataBits, parity: Option<Parity>, stop_bits: StopBits, ) -> UartConfig

Create a new instance of UartConfig